News #2:
Just fixed a huge memory bottleneck. Total core benchmark execution dropped from ~2.4s to ~484ms.
By leveraging the TAST to avoid unnecessary deep clones on ADT field accessors, native memory management for functional data structures gives:
- Red-Black Tree: ~1.98s ➔ ~61 ms (32x faster)
- List Processing: ~1.2ms ➔ ~82 μs (15x faster)
- Prime Sieve: ~8.2ms ➔ ~615 μs (13x faster)
I think purust can now be made public.
Still a lot to optimize.